%{?mingw_package_header}

%global pkgname exiv2

Name:          mingw-%{pkgname}
Version:       0.27
Release:       3%{?dist}
Summary:       MinGW Windows %{pkgname} library
License:       GPLv2+
BuildArch:     noarch
URL:           http://www.exiv2.org/
Source0:       https://github.com/Exiv2/%{pkgname}/archive/%{version}/%{pkgname}-%{version}.tar.gz

# Include windows.h generally if WIN32 is defined, not only if MSC_VER is defined
Patch0:        exiv2_win32.patch

# Fix undefined reference to BasicError<T>::setMsg
# (Some issue with dllexport/dllimport and a template specialization in a source
# file... So just moved the implementation out and made it inline.)
Patch1:        exiv2_setMsg.patch
# Install cmake files to correct location
Patch2:        exiv2_cmake.patch
# Rename xmp to exiv2-xmp to avoid name conflicts
Patch3:        exiv2_rename-xmp.patch
# Prevent a denial-service-attack related to XML entity expansion
# ("billion laughs attack").
# See https://bugzilla.redhat.com/show_bug.cgi?id=888769
Patch4:        exiv2_DBanAllEntityUsage.patch
# Backport fix for CVE-2018-2009{6,7,8,9}
# See https://github.com/Exiv2/exiv2/pull/706/commits/9296067b95b39bc055112b91d2f4031b7b542aec
Patch5:        exiv2_CVE-2018-2009X.patch


BuildRequires: cmake
BuildRequires: gettext

BuildRequires: mingw32-filesystem >= 95
BuildRequires: mingw32-gcc-c++
BuildRequires: mingw32-expat
BuildRequires: mingw32-win-iconv
BuildRequires: mingw32-zlib

BuildRequires: mingw64-filesystem >= 95
BuildRequires: mingw64-gcc-c++
BuildRequires: mingw64-expat
BuildRequires: mingw64-win-iconv
BuildRequires: mingw64-zlib


%description
MinGW Windows %{pkgname} library.


%package -n mingw32-%{pkgname}
Summary:       MinGW Windows %{pkgname} library

%description -n mingw32-%{pkgname}
MinGW Windows %{pkgname} library.


%package -n mingw64-%{pkgname}
Summary:       MinGW Windows %{pkgname} library

%description -n mingw64-%{pkgname}
MinGW Windows %{pkgname} library.


%{?mingw_debug_package}


%prep
%autosetup -p1 -n %{pkgname}-%{version}


%build
%mingw_cmake \
  -DEXIV2_BUILD_PO:BOOL=ON \
  -DEXIV2_BUILD_SAMPLES:BOOL=OFF \
  -DCMAKE_NO_SYSTEM_FROM_IMPORTED=ON

# Hack around double slashes install paths in generated po/cmake_install.cmake
# sed -i 's|//|/|g' build_win32/po/cmake_install.cmake
# sed -i 's|//|/|g' build_win64/po/cmake_install.cmake

%mingw_make %{?_smp_mflags}


%install
%mingw_make DESTDIR=%{buildroot} install
%mingw_find_lang exiv2

rm -f %{buildroot}%{mingw32_libdir}/pkgconfig/exiv2.lsm
rm -f %{buildroot}%{mingw32_datadir}/man/man1/exiv2.1
rm -f %{buildroot}%{mingw64_libdir}/pkgconfig/exiv2.lsm
rm -f %{buildroot}%{mingw64_datadir}/man/man1/exiv2.1



%files -n mingw32-%{pkgname} -f mingw32-%{pkgname}.lang
%license COPYING
%{mingw32_bindir}/exiv2.exe
%{mingw32_bindir}/libexiv2.dll
%{mingw32_libdir}/libexiv2.dll.a
%{mingw32_libdir}/libexiv2-xmp.a
%{mingw32_libdir}/cmake/exiv2/exiv2Config.cmake
%{mingw32_libdir}/cmake/exiv2/exiv2Config-noconfig.cmake
%{mingw32_libdir}/pkgconfig/exiv2.pc
%{mingw32_includedir}/exiv2/


%files -n mingw64-%{pkgname} -f mingw64-%{pkgname}.lang
%license COPYING
%{mingw64_bindir}/exiv2.exe
%{mingw64_bindir}/libexiv2.dll
%{mingw64_libdir}/libexiv2.dll.a
%{mingw64_libdir}/libexiv2-xmp.a
%{mingw64_libdir}/cmake/exiv2/exiv2Config.cmake
%{mingw64_libdir}/cmake/exiv2/exiv2Config-noconfig.cmake
%{mingw64_libdir}/pkgconfig/exiv2.pc
%{mingw64_includedir}/exiv2/


%changelog
* Tue Apr 02 2019 Sandro Mani <manisandro@gmail.com> - 0.27-3
- Backport fix for CVE-2018-2009{6,7,8,9}

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.27-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Jan 30 2019 Sandro Mani <manisandro@gmail.com> - 0.27-1
- Update to 0.27

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.26-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.26-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Jul 11 2017 Sandro Mani <manisandro@gmail.com> - 0.26-1
- Update to 0.26

* Tue Jan 17 2017 Sandro Mani <manisandro@gmail.com> - 0.25-1
- Initial package
